import os
import requests

from config import GITHUB_TOKEN, USERNAME

def fetch_user_data():
    headers = {"Authorization": f"token {GITHUB_TOKEN}"}
    user_url = f"https://api.github.com/users/{USERNAME}"
    repos_url = f"https://api.github.com/users/{USERNAME}/repos"

    try:
        print(f"Запрос к API GitHub: {user_url}")  # Отладочная информация
        # Получение общей информации о пользователе
        user_response = requests.get(user_url, headers=headers)
        print(f"Статус ответа (пользователь): {user_response.status_code}")  # Отладочная информация
        user_data = user_response.json()

        if user_response.status_code != 200:
            print(f"Ошибка при получении данных пользователя: {user_data}")
            return None, None

        print(f"Запрос к API GitHub: {repos_url}")  # Отладочная информация
        # Получение информации о репозиториях пользователя
        repos_response = requests.get(repos_url, headers=headers)
        print(f"Статус ответа (репозитории): {repos_response.status_code}")  # Отладочная информация
        repos_data = repos_response.json()

        if repos_response.status_code != 200:
            print(f"Ошибка при получении данных репозиториев: {repos_data}")
            return user_data, []

        return user_data, repos_data

    except Exception as e:
        print(f"Ошибка при выполнении запроса: {e}")
        return None, None


def save_to_file(user_data, repos_data):
    with open("output.txt", "w", encoding="utf-8") as file:
        # Запись личной информации
        file.write(f"Имя пользователя: {user_data.get('name', 'Не указано')}\n")
        file.write(f"Логин: {user_data.get('login', 'Не указано')}\n")
        file.write(f"E-mail: {user_data.get('email', 'Не указано')}\n")
        file.write(f"Биография: {user_data.get('bio', 'Не указана')}\n")
        file.write("\n")

        # Запись информации о репозиториях
        if not repos_data:
            file.write("Список репозиториев:\n")
            file.write("Нет доступных репозиториев.\n")
        else:
            file.write("Список репозиториев:\n")
            for repo in repos_data:
                file.write(f"- Название: {repo.get('name', 'Не указано')}\n")
                file.write(f"  Описание: {repo.get('description', 'Отсутствует')}\n")
                file.write(f"  URL: {repo.get('html_url', 'Отсутствует')}\n")
                file.write(f"  Звезды: {repo.get('stargazers_count', 0)}\n")
                file.write("\n")


def main():
    user_data, repos_data = fetch_user_data()
    if user_data and repos_data is not None:
        save_to_file(user_data, repos_data)
        print("Данные успешно сохранены в файл output.txt")
    else:
        print("Не удалось получить данные. Проверьте токен и имя пользователя.")


if __name__ == "__main__":
    main()